==> knative-model-4.4.1-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/TriggerFilterFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TriggerFilterFluent<A extends TriggerFilterFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildSourceAndType instead.
 * @return The buildable object.
 */
@Deprecated public TriggerFilterSourceAndType getSourceAndType();
    public TriggerFilterSourceAndType buildSourceAndType();
    public A withSourceAndType(TriggerFilterSourceAndType sourceAndType);
    public Boolean hasSourceAndType();
    public A withNewSourceAndType(String source,String type);
    public TriggerFilterFluent.SourceAndTypeNested<A> withNewSourceAndType();
    public TriggerFilterFluent.SourceAndTypeNested<A> withNewSourceAndTypeLike(TriggerFilterSourceAndType item);
    public TriggerFilterFluent.SourceAndTypeNested<A> editSourceAndType();
    public TriggerFilterFluent.SourceAndTypeNested<A> editOrNewSourceAndType();
    public TriggerFilterFluent.SourceAndTypeNested<A> editOrNewSourceAndTypeLike(TriggerFilterSourceAndType item);

    public interface SourceAndTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TriggerFilterSourceAndTypeFluent<TriggerFilterFluent.SourceAndTypeNested<N>>{

        
    public N and();    public N endSourceAndType();
}


}

==> knative-model-4.10.0-sources.jar: annotations/io/fabric8/knative/eventing/v1alpha1/TriggerFilterFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TriggerFilterFluent<A extends TriggerFilterFluent<A>> extends Fluent<A>{


    public A addToAttributes(String key,String value);
    public A addToAttributes(Map<String,String> map);
    public A removeFromAttributes(String key);
    public A removeFromAttributes(Map<String,String> map);
    public Map<String,String> getAttributes();
    public A withAttributes(Map<String,String> attributes);
    public Boolean hasAttributes();
    
/**
 * This method has been deprecated, please use method buildSourceAndType instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public TriggerFilterSourceAndType getSourceAndType();
    public TriggerFilterSourceAndType buildSourceAndType();
    public A withSourceAndType(TriggerFilterSourceAndType sourceAndType);
    public Boolean hasSourceAndType();
    public A withNewSourceAndType(String source,String type);
    public TriggerFilterFluent.SourceAndTypeNested<A> withNewSourceAndType();
    public TriggerFilterFluent.SourceAndTypeNested<A> withNewSourceAndTypeLike(TriggerFilterSourceAndType item);
    public TriggerFilterFluent.SourceAndTypeNested<A> editSourceAndType();
    public TriggerFilterFluent.SourceAndTypeNested<A> editOrNewSourceAndType();
    public TriggerFilterFluent.SourceAndTypeNested<A> editOrNewSourceAndTypeLike(TriggerFilterSourceAndType item);

    public interface SourceAndTypeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TriggerFilterSourceAndTypeFluent<TriggerFilterFluent.SourceAndTypeNested<N>>{

        
    public N and();    public N endSourceAndType();
}


}
